Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(374)

Unified Diff: src/hydrogen.cc

Issue 1140743004: Generalize builtins inlining flag to allow forced inlining of any function (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Fix comment Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/flag-definitions.h ('k') | src/math.js » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/hydrogen.cc
diff --git a/src/hydrogen.cc b/src/hydrogen.cc
index 86bf7634296dcbf71b8a2debf27262464a1a1e3c..5bf9f7b0d154f66c9e924695dc3c5dd2f1df0987 100644
--- a/src/hydrogen.cc
+++ b/src/hydrogen.cc
@@ -7951,9 +7951,12 @@ int HOptimizedGraphBuilder::InliningAstSize(Handle<JSFunction> target) {
Handle<JSFunction> caller = current_info()->closure();
Handle<SharedFunctionInfo> target_shared(target->shared());
- // Always inline builtins marked for inlining.
+ // Always inline functions that force inlining.
+ if (target_shared->force_inline()) {
+ return 0;
+ }
if (target->IsBuiltin()) {
- return target_shared->inline_builtin() ? 0 : kNotInlinable;
+ return kNotInlinable;
}
if (target_shared->IsApiFunction()) {
« no previous file with comments | « src/flag-definitions.h ('k') | src/math.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698